from setuptools import setup

setup(name='ftThanos',
version="0.0.74",
description="A client for 74 API",
author="Thanos 74",
author_email="thanos@74paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
